<?php
##############################################################################
# G5-Scripts.de PHP Newsletter Script
# Copyright 2004-2016 G5-Scripts.de webmaster@G5-Scripts.de
# Last Modified                26.02.2016
# G5-Scripts.de                http://www.G5-Scripts.de
# Version                      1.3.0
##############################################################################
# Lizenzbedingungen (gekürzte Fassung)
# Copyright 2004-2016 G5-Scripts.de  All Rights Reserved.
# 
# Mit dem Herunterladen bzw. Erwerb der hier angebotenen Software erkennen die Nutzer 
# ausdrücklich die Lizenzbestimmungen gelesen und diese anerkannt zu haben.
#
# Beim Einsatz der Software im rein privaten Bereich ohne kommerzielle oder gewerbliche Absicht, 
# ist die Software für die Nutzung kostenfrei. Für die kommerzielle Nutzung sowie 
# eine optionale Entfernung des Copyright Hinweises ist eine geeignete Lizenz zu erwerben.
#
# Diese Software darf im rein privaten Bereich frei benutzt werden, 
# solange alle Copyright bzw. Powered By Verweise auf G5-Scripts.de, 
# eingebaut innerhalb der Software, erhalten bleibt. Diese müssen für Benutzer sichtbar sein 
# und in unveränderter Form dargestellt werden.
#
# Die Original-Software unverändert darf weitergegeben, jedoch nicht verkauft
# oder wiederverkauft werden.
# Die angepasste bzw. veränderte Software und Teile dieser dürfen nicht
# weitergegeben, verkauft oder wiederverkauft werden.
#
# Die vollständige Fassung der Lizenzbedingungen finden Sie unter:
# http://www.g5-scripts.de/scripte__newsletter_php__lizenzbedingungen.htm
#
##############################################################################


class NSLetter
{
    private $entityPath;
    private $doc;

    public $id;
	public $fileVesion = 2;	//ab v2 werden die werte mit base64 codiert, da es vorher probleme bei der speicherung langer html inhalte gab, diese haben in bestimmten fällen die xml struktur zerstört
    public $date;
    public $time;
    public $subscribers;
    public $categorie = array();
    public $format = "text";
    public $subject = "";
    public $message = "";
    public $header = "";
    public $footer = "";
	public $attachments = array();
	
    
    public function __construct($entityPath, $id)
    {
		$id = (int)$id;
        $this->doc = new DOMDocument('1.0', 'UTF-8');
        $this->doc->formatOutput = true; 
        $this->doc->appendChild($this->doc->createElement('Letter'));

        $this->id = $id;
        $this->entityPath = $entityPath."/".$this->id;

		date_default_timezone_set('Europe/Berlin');
		
        $this->date        = date("d.m.Y", $id);
		$this->time        = date("H:i", $id);
		$this->subscribers = 0;
    }
    
    public function Load()
    {
        $entityFile = $this->entityPath;
        
        if(file_exists($entityFile)){
            @$ret = $this->doc->load($entityFile);
            
            if($ret){
                //ist XML
				$this->fileVesion  = $this->getValue("FileVersion", 0);
				if($this->fileVesion=="")
					$this->fileVesion = 1;

				$this->categorie   = explode('|', $this->getValue("Categorie"));
				$this->format      = $this->getValue("Format");
				$this->subject     = $this->getValue("Subject");
				$this->message     = $this->getValue("Message");
				$this->header	   = $this->getValue("Header");
				$this->footer      = $this->getValue("Footer");
				$this->subscribers = $this->getValue("Subscribers");
				$this->attachments = $this->getValue("Attachments");
				
                return true;
            }else{
                //hat nicht geklappt, scheint noch altes format zu sein
				$this->fileVesion = 0;

				$inhalt        = file($entityFile);

				$this->categorie   = explode('|', trim($inhalt[1]));
				$this->format      = trim($inhalt[2]);
				$this->subject     = trim($inhalt[3]);
				$this->message     = trim(implode("",array_slice($inhalt,4,count($inhalt))));
				$this->subscribers = 0;
		
				$this->Save();
				
                return true;
            }
        }
        
        return false;
    }
    public function Save()
    {
        $entityFile = $this->entityPath;
		
		$this->setValue("FileVersion",  $this->fileVesion, 0);
		$this->setValue("Categorie",	implode('|', $this->categorie));
		$this->setValue("Format",		$this->format);
		$this->setValue("Subject",		$this->subject);
		$this->setValue("Message",		$this->message);
		$this->setValue("Header",		$this->header);
		$this->setValue("Footer",		$this->footer);
		$this->setValue("Subscribers",	$this->subscribers);
		$this->setValue("Attachments",	implode('|', $this->attachments));

        $this->doc->save($entityFile);
		@chmod($entityFile, 0644);
    }
    
	public function IsHTML(){return $this->format == "html" ? true : false;}
	public function IsText(){return $this->format == "text" ? true : false;}

	private function getValue($tagName, $decode=1){
        $val = "";
        $node = $this->doc->getElementsByTagName($tagName)->item(0);
        if($node != null){
			if($this->format == "html")
				$val = trim($node->nodeValue);
			else
				$val = $node->nodeValue;
			
			if($decode==1 && $this->fileVesion >= 2)
				$val = base64_decode($val);
        }
        return $val;
    }
	private function setValue($tagName, $value, $encode=1){
		$root = $this->doc->getElementsByTagName("Letter")->item(0);
        $node = $this->doc->getElementsByTagName($tagName)->item(0);
        if($this->format == "html"){
			$value = trim($value, "\n");		#darf nicht beim html format
			$value = trim($value, "\r");
			$value = trim($value, "\t");
		}
		$value = $this->_convert($value);
		
		if($encode==1 && $this->fileVesion >= 2)
			$value = base64_encode($value);
		
        $value = $this->doc->createCDATASection($value);
		
        if($node != null){
			$root->removeChild($node);
		}
            
        $newNode = $this->doc->createElement($tagName);
        $newNode->appendChild($value);
        
        $root->appendChild($newNode);
    }
	
    private function _convert($content) {
		if(!mb_check_encoding($content, 'UTF-8') OR !($content === mb_convert_encoding(mb_convert_encoding($content, 'UTF-32', 'UTF-8' ), 'UTF-8', 'UTF-32'))) {
			$content = mb_convert_encoding($content, 'UTF-8');
		}
		return $content;
    }
}

?>